@@ -12,9 +12,9 @@ OC.L10N.register(
     "Open »%s«" : "Buka »%s«",
     "Cheers!" : "Horee!",
     "Upcoming events" : "Acara mendatang",
-    "More events" : "Lebih banyak acara",
     "No more events today" : "Tidak ada acara lagi hari ini",
     "No upcoming events" : "Tdak ada acara mendatang",
+    "More events" : "Lebih banyak acara",
     "%1$s with %2$s" : "%1$sdengan %2$s",
     "Calendar" : "Kalender",
     "New booking {booking}" : "Pemesanan baru (pemesanan)",
@@ -60,7 +60,7 @@ OC.L10N.register(
     "Delete" : "Hapus",
     "Appointment link was copied to clipboard" : "Tautan janji temu disalin ke papan klip",
     "Appointment link could not be copied to clipboard" : "Tautan janji temu tidak dapat disalin ke papan klip",
-    "Add new" : "Tambahkan baru",
+    "Create new" : "Buat",
     "Untitled calendar" : "Kalender tanpa judul",
     "Shared with you by" : "Dibagikan dengan Anda oleh",
     "Edit and share calendar" : "Edit dan bagikan kalender",
@@ -73,6 +73,7 @@ OC.L10N.register(
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Batal berbagi kalender dalam {countdown} detik"],
     "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Menghapus kalender dalam {countdown} detik"],
     "Calendars" : "Kalender",
+    "Add new" : "Tambahkan baru",
     "New calendar" : "Kalender baru",
     "Name for new calendar" : "Nama untuk kalender baru",
     "Creating calendar …" : "Membuat kalender …",
@@ -274,7 +275,6 @@ OC.L10N.register(
     "Personal" : "Pribadi",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Deteksi zona waktu otomatis menetapkan UTC sebagai zona waktu Anda. Hal ini kemungkinan besar disebabkan oleh langkah keamanan peramban web Anda. Harap setel zona waktu Anda secara manual di pengaturan kalender.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Zona waktu Anda yang terkonfigurasi ({timezoneId}) tidak ditemukan. Kembali ke UTC.\nHarap ubah zona waktu Anda di pengaturan dan laporkan masalah ini.",
-    "[Today]" : "[Hari ini]",
     "Details" : "Detail",
     "Resources" : "Sumber daya",
     "Close" : "Tutup",
@@ -325,7 +325,6 @@ OC.L10N.register(
     "Other" : "Lainnya",
     "The visibility of this event in shared calendars." : "Visibilitas acara ini di kalender yang dibagikan.",
     "Add a location" : "Tambah lokasi",
-    "Add a description" : "Tambah deskripsi",
     "Status" : "Status",
     "Confirmed" : "Terkonfirmasi",
     "Confirmation about the overall status of the event." : "Konfirmasi tentang status keseluruhan acara.",
@@ -339,6 +338,8 @@ OC.L10N.register(
     "Special color of this event. Overrides the calendar-color." : "Warna spesial dari acara ini. Mengganti warna kalender.",
     "Chat room for event" : "Ruang obrolan untuk acara",
     "An error occurred, unable to delete the calendar." : "Terjadi galat, tidak dapat menghapus kalender.",
-    "This is an event reminder." : "Ini adalah pengingat acara."
+    "This is an event reminder." : "Ini adalah pengingat acara.",
+    "[Today]" : "[Hari ini]",
+    "Add a description" : "Tambah deskripsi"
 },
 "nplurals=1; plural=0;");
