@@ -20,6 +20,7 @@ OC.L10N.register(
     "Copy link" : "Kopjo linkun",
     "Edit" : "Përpuno",
     "Delete" : "Fshije",
+    "Create new" : "Krijo të ri",
     "New calendar" : "Kalendar i ri",
     "Export" : "Eksport",
     "Name" : "Emri",
@@ -53,6 +54,7 @@ OC.L10N.register(
     "Sunday" : "E dielë",
     "Update" : "Përditësoje",
     "Your email address" : "Adresa juaj email",
+    "Back" : "Mbrapsht",
     "Notification" : "Njoftim",
     "Email" : "Emaili",
     "Delete file" : "Fshi skedarin",
